/*!
\file typedefs.h
\brief General typedefs for SkyViewer
\author Nicholas Phillips, phillips@friday.gsfc.nasa.gov
\date Jul 29, 2004
*/
#ifndef TYPEDEFS_H
#define TYPEDEFS_H

#include <vector>
#include <map>
#include <QGLViewer/qglviewer.h>

//! Vector of Qt colors
typedef std::vector<QRgb> ColorTable;
//! A skymap -> texture Look Up Table
typedef std::vector<long> PixLUT;
//! Where to cache the computed texture Look Up Tables
typedef std::map<int, PixLUT > PixLUTCache;

//! Possible values to display
enum DisplayValue { temperature, Qpolarization, Upolarization, NumObs};

//=======================================================================
/*!
	The information and actions I need for a OpenGL vertex.
	Includes 3d position and associated texture coord.
@author Nicholas Phillips
*/
class GLPoint {
public:
	float x,y,z;
	float s,t;
	void setVert(double x_, double y_, double z_) { x = x_; y = y_; z = z_;}
	void setVert(double theta, double phi)
		{ x = cos(phi)*sin(theta); y = sin(phi)*sin(theta); z = cos(theta);}
	void setTex(double s_, double t_) { s = s_; t = t_; }
	void glSet() { glTexCoord2f( s,t); glVertex3f( x, y, z); }

};
//=======================================================================
//! A vevtor of my GLPoint's
typedef std::vector<GLPoint> GLVertices;
typedef GLVertices::iterator GLVertI;
typedef std::list<GLVertices> GLVertList;
typedef GLVertList::iterator GLVertLI;

#endif
